@@ -238,10 +238,12 @@ def view(obj, follow, since=0):
         if time.time() - last_info_time > 5:
             print()
             log_info(obj['queue'])
-            print("\033[34m", "; ".join(f"{k}: {v}" for k,v in obj['queue'].summary.items()), "\033[0m")
 
-            recent_workers = [k for k,v in active_workers.items() if v>time.time()-120]
-            print(f"\033[35m{len(recent_workers)} recent workers: {recent_workers}\033[0m")
+            for q in obj['queue'].list_queues(None):
+                print("\033[34m", "; ".join(f"{k}: {v}" for k,v in obj['queue'].summary.items()), "\033[0m")
+
+            recent_workers = [k for k,v in active_workers.items() if v>time.time()-30]
+            print(f"\033[35m{len(recent_workers)} recent workers\033[0m: {', '.join(recent_workers)}")
 
             last_info_time = time.time()
 
@@ -326,7 +328,7 @@ def guardian(obj, watch):
         # stats
 
         print("getting queue statistics...")
-        for k,v in obj['queue'].info.items():
+        for k,v in obj['queue'].summary.items():
             print(k, ":", v, end="; ")
         print("\n")
 
